@@ -1160,6 +1160,11 @@ def select_tier():
 
 
 def get_solution_stack(solution_string, region):
+    #If string is explicit, do not check
+    if re.match('\d\dbit Amazon Linux [0-9.]+ v[0-9.]+ running .*', solution_string):
+        return SolutionStack(solution_string)
+
+
     solution_string = solution_string.lower()
     solution_stacks = elasticbeanstalk.get_available_solution_stacks(region)
 
